@@ -82,7 +82,7 @@ pkgconfig_name <- function(){
   pc <- Sys.getenv('PKG_CONFIG', "")
   if(is_string(pc))
     return(pc)
-  ifelse(is_windows(), make_echo('$(BINPREF)pkg-config'), 'pkg-config')
+  ifelse(is_windows(), make_echo('$(BINPREF)pkg-config.exe'), 'pkg-config')
 }
 
 pkgconfig_path <- function(name = pkgconfig_name(), error = TRUE){
